[![Documentation Status](https://readthedocs.org/projects/assyst/badge/?version=stable)](https://assyst.readthedocs.io/stable/?badge=stable)

# ASSYST or _Automated Small SYmmetric Structure Training_

A minimal reference implementation of ASSYST method to generate transferable training data for machine learning potentials, see also the corresponding [paper](https://doi.org/10.1038/s41524-025-01669-4).

Please use the following citation when referencing the method in your work.

```
@article{poul2025automated,
  title={Automated generation of structure datasets for machine learning potentials and alloys},
  volume={11},
  DOI={10.1038/s41524-025-01669-4},
  number={1},
  journal={npj Computational Materials},
  author={Poul, Marvin and Huber, Liam and Neugebauer, J\"org},
  year={2025},
  month={Jun}
}
```
